==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Shape/ShapePolygonAFPP/ts/ShapePolygonAFPP_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>ShapePolygonAFPP</name>
    <message>
        <location filename="../ShapePolygonAFPP.js" line="+59"/>
        <source>First side</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>First Corner</source>
        <translation>第１の頂点</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Second side</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Second Corner</source>
        <translation>第２の頂点</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../ShapePolygonAFPPInit.js" line="+2"/>
        <source>Polygo&amp;n (Side, Side)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw regular polygon from middle points of two opposite sides or two opposite corners</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ShapePolygonAFPP.ui" line="+17"/>
        <source>Corners:</source>
        <translation>頂点:</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Corner to Corner</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Shape/ShapePolygonAFPP/ts/ShapePolygonAFPP_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ShapePolygonAFPP</name>
    <message>
        <location filename="../ShapePolygonAFPP.js" line="+59"/>
        <source>First side</source>
        <translation>最初の辺</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>First Corner</source>
        <translation>第１の頂点</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Second side</source>
        <translation>２番目の辺</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Second Corner</source>
        <translation>第２の頂点</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../ShapePolygonAFPPInit.js" line="+2"/>
        <source>Polygo&amp;n (Side, Side)</source>
        <translation>多角形（辺、辺）</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw regular polygon from middle points of two opposite sides or two opposite corners</source>
        <translation>辺の中心と反対側の辺または頂点から正多角形を描く</translation>
    </message>
    <message>
        <location filename="../ShapePolygonAFPP.ui" line="+17"/>
        <source>Corners:</source>
        <translation>頂点:</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Corner to Corner</source>
        <translation>頂点から頂点</translation>
    </message>
</context>
</TS>
